Authors
=======

``nobot`` was previously developed under the name `django-recaptcha` and under the
Copyright of Praekelt Foundation. The following copyright notice holds true for
releases before the renaming: "Copyright (c) by Praekelt Foundation

Package Maintainer
------------------
* Christopher Grebs

Praekelt Consulting
-------------------
* Shaun Sephton
* Peter Pistorius
* Hedley Roos

bTaylor Design
--------------
* `Brandon Taylor <http://btaylordesign.com/>`_

Other
-----
* Brooks Travis
* `Denis Mishchishin <https://github.com/denz>`_
* `Joshua Peper <https://github.com/zout>`_
* `Rodrigo Primo <https://github.com/rodrigoprimo>`_
* `snnwolf <https://github.com/snnwolf>`_
* `Adriano Orioli <https://github.com/Aorioli>`_
* `cdvv7788 <https://github.com/cdvv7788>`_
